@@ -140,6 +140,11 @@ class MeshDevice:
         ret = True if conns else False
         return ret
 
+    @property
+    def ui_type(self) -> Optional[str]:
+        """Get the type assigned to the device as per the web UI."""
+        return self._get_user_property(name="userDeviceType")
+
     @property
     def unique_id(self) -> str:
         """Return the device_id as unique_id."""
